@@ -11,9 +11,6 @@
 #include "xf86.h"
 #include "xf86_OSproc.h"
 
-/* This is used for module versioning */
-#include "xf86Version.h"
-
 /* All drivers initialising the SW cursor need this */
 #include "mipointer.h"
 
@@ -50,7 +47,7 @@
 #include "servermd.h"
 #ifdef XFreeXDGA
 #define _XF86DGA_SERVER_
-#include <X11/extensions/xf86dgastr.h>
+#include <X11/extensions/xf86dgaproto.h>
 #endif
 
 /* Mandatory functions */
@@ -88,6 +85,9 @@ static Bool	dummyDriverFunc(ScrnInfoPtr pScrn, xorgDriverFuncOp op,
 #define DUMMY_MINOR_VERSION PACKAGE_VERSION_MINOR
 #define DUMMY_PATCHLEVEL PACKAGE_VERSION_PATCHLEVEL
 
+#define DUMMY_MAX_WIDTH 32767
+#define DUMMY_MAX_HEIGHT 32767
+
 /*
  * This is intentionally screen-independent.  It indicates the binding
  * choice made in the first PreInit.
@@ -128,30 +128,6 @@ static const OptionInfoRec DUMMYOptions[] = {
     { -1,                  NULL,           OPTV_NONE,	{0}, FALSE }
 };
 
-
-/*
- * List of symbols from other modules that this module references.  This
- * list is used to tell the loader that it is OK for symbols here to be
- * unresolved providing that it hasn't been told that they haven't been
- * told that they are essential via a call to xf86LoaderReqSymbols() or
- * xf86LoaderReqSymLists().  The purpose is this is to avoid warnings about
- * unresolved symbols that are not required.
- */
-
-static const char *fbSymbols[] = {
-    "fbPictureInit",
-    "fbScreenInit",
-    NULL
-};
-
-static const char *ramdacSymbols[] = {
-    "xf86CreateCursorInfoRec",
-    "xf86DestroyCursorInfoRec",
-    "xf86InitCursor",
-    NULL
-};
-
-
 #ifdef XFree86LOADER
 
 static MODULESETUPPROTO(dummySetup);
@@ -190,11 +166,6 @@ dummySetup(pointer module, pointer opts, int *errmaj, int *errmin)
 	 * by calling LoadSubModule().
 	 */
 
-	/*
-	 * Tell the loader about symbols from other modules that this module
-	 * might refer to.
-	 */
-	LoaderRefSymLists(fbSymbols, ramdacSymbols, NULL);
 	/*
 	 * The return value must be non-NULL on success even though there
 	 * is no TearDownProc.
@@ -231,7 +202,7 @@ DUMMYFreeRec(ScrnInfoPtr pScrn)
 {
     if (pScrn->driverPrivate == NULL)
 	return;
-    xfree(pScrn->driverPrivate);
+    free(pScrn->driverPrivate);
     pScrn->driverPrivate = NULL;
 }
 
@@ -386,7 +357,7 @@ DUMMYPreInit(ScrnInfoPtr pScrn, int flags)
 
     xf86CollectOptions(pScrn, device->options);
     /* Process the options */
-    if (!(dPtr->Options = xalloc(sizeof(DUMMYOptions))))
+    if (!(dPtr->Options = malloc(sizeof(DUMMYOptions))))
 	return FALSE;
     memcpy(dPtr->Options, DUMMYOptions, sizeof(DUMMYOptions));
 
@@ -434,8 +405,9 @@ DUMMYPreInit(ScrnInfoPtr pScrn, int flags)
 	int apertureSize = (pScrn->videoRam * 1024);
 	i = xf86ValidateModes(pScrn, pScrn->monitor->Modes,
 			      pScrn->display->modes, clockRanges,
-			      NULL, 256, 2048,(8 * pScrn->bitsPerPixel),
-			      128, 2048, pScrn->display->virtualX,
+			      NULL, 256, DUMMY_MAX_WIDTH,
+			      (8 * pScrn->bitsPerPixel),
+			      128, DUMMY_MAX_HEIGHT, pScrn->display->virtualX,
 			      pScrn->display->virtualY, apertureSize,
 			      LOOKUP_BEST_REFRESH);
 
@@ -473,12 +445,10 @@ DUMMYPreInit(ScrnInfoPtr pScrn, int flags)
     if (xf86LoadSubModule(pScrn, "fb") == NULL) {
 	RETURN;
     }
-    xf86LoaderReqSymLists(fbSymbols, NULL);
 
     if (!dPtr->swCursor) {
 	if (!xf86LoadSubModule(pScrn, "ramdac"))
 	    RETURN;
-	xf86LoaderReqSymLists(ramdacSymbols, NULL);
     }
     
     /* We have no contiguous physical fb in physical memory */
@@ -565,7 +535,7 @@ DUMMYScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
     DUMMYScrn = pScrn;
 
 
-    if (!(dPtr->FBBase = xalloc(pScrn->videoRam * 1024)))
+    if (!(dPtr->FBBase = malloc(pScrn->videoRam * 1024)))
 	return FALSE;
     
     /*
@@ -622,7 +592,9 @@ DUMMYScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv)
 
     xf86SetBlackWhitePixels(pScreen);
 
+#ifdef XFreeXDGA
     DUMMYDGAInit(pScreen);
+#endif
     
     if (dPtr->swCursor)
 	xf86DrvMsg(scrnIndex, X_CONFIG, "Using Software Cursor.\n");
@@ -735,7 +707,7 @@ DUMMYCloseScreen(int scrnIndex, ScreenPtr pScreen)
 
     if(pScrn->vtSema){
  	dummyRestore(pScrn, TRUE);
-	xfree(dPtr->FBBase);
+	free(dPtr->FBBase);
     }
 
     if (dPtr->CursorInfo)
@@ -793,25 +765,31 @@ dummyModeInit(ScrnInfoPtr pScrn, DisplayModePtr mode)
     return(TRUE);
 }
 
-
 Atom VFB_PROP  = 0;
 #define  VFB_PROP_NAME  "VFB_IDENT"
 
-
-
 static Bool
 DUMMYCreateWindow(WindowPtr pWin)
 {
+    ScreenPtr pScreen = pWin->drawable.pScreen;
     DUMMYPtr dPtr = DUMMYPTR(DUMMYScrn);
     WindowPtr pWinRoot;
     int ret;
-	
-    ret = dPtr->CreateWindow(pWin);
+
+    pScreen->CreateWindow = dPtr->CreateWindow;
+    ret = pScreen->CreateWindow(pWin);
+    dPtr->CreateWindow = pScreen->CreateWindow;
+    pScreen->CreateWindow = DUMMYCreateWindow;
+
     if(ret != TRUE)
 	return(ret);
 	
     if(dPtr->prop == FALSE) {
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 8
         pWinRoot = WindowTable[DUMMYScrn->pScreen->myNum];
+#else
+        pWinRoot = DUMMYScrn->pScreen->root;
+#endif
         if (! ValidAtom(VFB_PROP))
             VFB_PROP = MakeAtom(VFB_PROP_NAME, strlen(VFB_PROP_NAME), 1);
 
@@ -826,6 +804,9 @@ DUMMYCreateWindow(WindowPtr pWin)
     return TRUE;
 }
 
+#ifndef HW_SKIP_CONSOLE
+#define HW_SKIP_CONSOLE 4
+#endif
 
 static Bool
 dummyDriverFunc(ScrnInfoPtr pScrn, xorgDriverFuncOp op, pointer ptr)
@@ -835,7 +816,7 @@ dummyDriverFunc(ScrnInfoPtr pScrn, xorgDriverFuncOp op, pointer ptr)
     switch (op) {
 	case GET_REQUIRED_HW_INTERFACES:
 	    flag = (CARD32*)ptr;
-	    (*flag) = 0;
+	    (*flag) = HW_SKIP_CONSOLE;
 	    return TRUE;
 	default:
 	    return FALSE;
